@@ -1,9 +1,8 @@
-/* TLSv1 filter for STARTTLS extension.
+/* simple wrapper program for STARTTLS
 
-   Copyright (C) 1999, 2000 Daiki Ueno <ueno@unixuser.org>
+   Copyright (C) 1999, 2000 Free Software Foundation, Inc.
 
    Author: Daiki Ueno <ueno@unixuser.org>
-	Kenichi OKADA <okada@opaopa.org>
    Created: 1999-11-19
    Keywords: TLS, OpenSSL
 
@@ -26,14 +25,6 @@
 
 */
 
-/*
-  How to compile: (OpenSSL is required)
-  
-  gcc -I/usr/local/ssl/include -o starttls starttls.c \
-    -L/usr/local/ssl/lib -lssl -lcrypto
-
-*/
-
 #include <sys/types.h>
 #include <stdio.h>
 #include <stdlib.h>
@@ -41,8 +32,6 @@
 
 #include <unistd.h>
 
-/* OpenSSL library. */
-
 #include <openssl/lhash.h>
 #include <openssl/bn.h>
 #include <openssl/err.h>
@@ -54,9 +43,9 @@
 #include <socks.h>
 #endif 
 
-#ifndef HAVE_GETADDRINFO
-#include "getaddrinfo.h"
-#endif /* !HAVE_GETADDRINFO */
+#ifdef NEED_ADDRINFO_H
+#include "addrinfo.h"
+#endif
 
 #include <sys/time.h>
 #include <sys/socket.h>
@@ -71,33 +60,12 @@
 #define _GNU_SOURCE
 #include <getopt.h>
 
-#ifdef HAVE_BASENAME
-# ifdef HAVE_LIBGEN_H
-#  include <libgen.h>
-#  ifdef basename
-#   undef basename
-#  endif
-# endif
-# include <string.h>
-#else
-inline char *
-basename(path) 
-     const char *path;
-{ 
-  char *p = rindex((path), '/');
-  return p ? p + 1 : (path);
-}
-#endif
-
-#define true 1
-
 static SSL_CTX *tls_ctx = NULL;
 static SSL *tls_conn = NULL;
 static int tls_fd;
 
 static char *opt_cert_file = NULL, *opt_key_file = NULL;
 static int  opt_verify = 0;
-static int opt_force;
 
 static int
 tls_ssl_ctx_new (cert_file, key_file)
@@ -223,8 +191,7 @@ usage (progname)
 	  "Options:\n\n"
 	  " --cert-file [file]      specify certificate file\n"
 	  " --key-file [file]       specify private key file\n"
-	  " --verify [level]        set verification level\n"
-	  " --force                 force negotiate\n",
+	  " --verify [level]        set verification level\n",
 	  progname, PACKAGE, VERSION, progname);
 }
      
@@ -246,7 +213,6 @@ main (argc, argv)
       {"cert-file", 1, 0, 'c'},
       {"key-file", 1, 0, 'k'},
       {"verify", 1, 0, 'v'},
-      {"force", 0, 0, 'f'},
       {0, 0, 0, 0}
     };
 
@@ -267,9 +233,6 @@ main (argc, argv)
 	case 'v':
 	  opt_verify = atoi (optarg);
 	  break;
-	case 'f':
-	  opt_force = true;
-	  break;
 	default:
 	  usage (basename (argv[0]));
 	  return 1;
@@ -295,9 +258,6 @@ main (argc, argv)
   act.sa_flags = SA_RESTART|SA_RESETHAND;
   sigaction (SIGALRM, &act, NULL);
 
-  if (opt_force == true)
-    tls_negotiate();
-
   while (1)
     {
       FD_SET (tls_fd, &readfds);
